@@ -1,20 +1,18 @@
 cv <-
-function (x, is.sample = TRUE, coefnorm = FALSE, weighting = NULL, wmean = FALSE, na.rm = FALSE)
-{ 
-  if (is.sample == TRUE)
+function (x, is.sample = TRUE, coefnorm = FALSE, weighting = NULL, wmean = FALSE, na.rm = TRUE)
 
+{ 
+
+  if (is.sample == TRUE)
   {
     n <- length(x)-1
-
   }
   else
-
   {
     n <- length(x)
-
   }
   
-  mean_x <- mean2 (x, weighting = weighting, output = "mean", na.rm = FALSE)
+  mean_x <- mean2 (x, weighting = weighting, output = "mean", na.rm = na.rm)
   
   sd_x <- sd2(x, is.sample = is.sample, weighting = weighting, wmean = wmean, na.rm = na.rm)
   
@@ -22,12 +20,10 @@ function (x, is.sample = TRUE, coefnorm = FALSE, weighting = NULL, wmean = FALSE
 
   if (coefnorm == FALSE) {
     return (v)
-
   }   
   
   if (coefnorm == TRUE) {
     v.norm <- v/sqrt(n)
-
     return(v.norm)
   }
   
