@@ -7,8 +7,7 @@ function (e_ij, e_j,
                        bg.col = "gray95", 
                        bgrid = TRUE, bgrid.col = "white", bgrid.size = 2, bgrid.type = "solid",
                        lcg = FALSE, lcgn = FALSE, lcg.caption = NULL, lcg.lab.x = 0, lcg.lab.y = 1, 
-                       add.lc = FALSE, plot.lc = TRUE) 
-  {
+                       add.lc = FALSE, plot.lc = TRUE) {
 
   e_i <- sum(e_ij)
 
