@@ -1,21 +1,26 @@
 hoover <-
-function (x, weighting = NULL)
+function (x, weighting = NULL, na.rm = TRUE)
 {
   
   if (!is.null(weighting))
-
   {
+    
+    if (na.rm == TRUE) {
+      weighting <- weighting[!is.na(weighting)]
+    }
+    
     if (length(x) != length(weighting))
-
     {
       stop("Frequency and weighting differ in length", call. = FALSE)
-
     }
   }
   
+  if (na.rm == TRUE) {
+    x <- x[!is.na(x)]
+  }
+  
   x_share <- x/sum(x)
 
-  
   if (is.null(weighting)) {
     w_share <- 1/length(x)
   }
@@ -24,7 +29,6 @@ function (x, weighting = NULL)
   }
 
   x_comp <- abs(x_share-w_share)
-
   x_comp_sum <- sum(x_comp)
 
   CI <- x_comp_sum/2
